#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor gtk3%{nil}
%if "%{flavor}" == "gtk2"
%global gtkver 2
%bcond_with mono
%define nsuffix -%{flavor}
%endif
%if "%{flavor}" == "gtk3"
%global psuffix 3
%global gtkver 3
%define nsuffix -%{flavor}
%bcond_with mono
%endif
%define sover 1
%define _version 12.10.1+20.10.20200706.1
Name:           libappindicator%{?nsuffix}
Version:        12.10.1~bzr20200706.298
Release:        3.1
Summary:        Application indicators library
License:        GPL-3.0-only AND LGPL-2.0-only AND LGPL-3.0-only
Group:          System/GUI/Other
URL:            https://launchpad.net/libappindicator
Source:         https://launchpad.net/ubuntu/+archive/primary/+files/libappindicator_%{_version}.orig.tar.gz
# PATCH-FIX-UPSTREAM 0001_Fix_mono_dir.patch hrvoje.senjan@gmail.com -- Fix location of .pc files.
Patch0:         0001_Fix_mono_dir.patch
# PATCH-FIX-OPENSUSE make_gtk_doc_optional.patch -- Do not require macros from gtk-doc
Patch1:         make_gtk_doc_optional.patch
# PATCH-FIX-OPENSUSE xappstatusicon.patch maurizio.galli@gmail.com -- Original patch by Linux Mint. Include support for XAppStatusIcon by Linux Mint
Patch2:         xappstatusicon.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gobject-introspection-1.0)
%if "%{flavor}" == ""
ExclusiveArch:  do-not-build
%endif
%if "%{flavor}" == "gtk2"
BuildRequires:  pkgconfig(dbusmenu-gtk-0.4)
BuildRequires:  pkgconfig(gtk+-2.0)
%if %{with mono}
BuildRequires:  pkgconfig(gapi-2.0)
BuildRequires:  pkgconfig(gtk-sharp-2.0)
BuildRequires:  pkgconfig(mono)
BuildRequires:  pkgconfig(nunit)
%endif
%else
BuildRequires:  vala
BuildRequires:  pkgconfig(dbusmenu-gtk3-0.4)
BuildRequires:  pkgconfig(gtk+-3.0)
#BuildRequires:  pkgconfig(xapp) >= 1.5.0
%endif
Provides:       libappindicator-gtk3

%description
A library to allow applications to export a menu into the Unity Menu bar. Based
on KSNI it also works in KDE and will fallback to generic Systray support if
none of those are available.

%package -n libappindicator%{?psuffix:%{psuffix}-}%{sover}
Summary:        Application indicators library
Group:          System/Libraries
# Fedora and friends compatibility symbol
%if "%{flavor}" == "gtk2"
Provides:       libappindicator = %{version}
%else
Provides:       libappindicator-gtk3 = %{version}
%endif

%description -n libappindicator%{?psuffix:%{psuffix}-}%{sover}
A library to allow applications to export a menu into the Unity Menu bar. Based
on KSNI it also works in KDE and will fallback to generic Systray support if
none of those are available.

%if "%{flavor}" != "gtk2"
%package -n typelib-1_0-AppIndicator%{?psuffix}-0_1
Summary:        Application indicators library
Group:          System/Libraries

%description -n typelib-1_0-AppIndicator%{?psuffix}-0_1
This package contains the GObject Introspection bindings for the appindicator
library.

%else

%package -n appindicator%{?psuffix}-sharp
Summary:        Application indicators library for C#
Group:          System/Libraries

%description -n appindicator%{?psuffix}-sharp
This package provides the appindicator-sharp assembly that allows CLI (.NET)
programs to take menus from applications and place them in the panel.

This package provides assemblies to be used by applications.

%package -n appindicator%{?psuffix}-sharp-devel
Summary:        Development files for libappindicator-sharp
Group:          Development/Libraries/Other
Requires:       appindicator%{?psuffix}-sharp = %{version}

%description -n appindicator%{?psuffix}-sharp-devel
This package contains the development files for the appindicator-sharp library.
%endif

%package -n libappindicator%{?psuffix}-devel
Summary:        Development files for libappindicator
Group:          Development/Libraries/C and C++
Requires:       libappindicator%{?psuffix:%{psuffix}-}%{sover} = %{version}

%description -n libappindicator%{?psuffix}-devel
This package contains the development files for the appindicator%{?psuffix} library.

%prep
%setup -q -c -n libappindicator-%{version}
%patch0 -p1
%patch1 -p1
#%%patch2 -p1

%build
# Create dummy file, to avoid dependency on gtk-doc
echo "EXTRA_DIST = " >> gtk-doc.make
autoreconf -vfi
%if %{with mono}
export CSC=%{_bindir}/gmcs
%endif

%configure \
  --disable-static    \
  --disable-gtk-doc   \
  --disable-mono-test \
  --with-gtk=%{gtkver}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%if "%{flavor}" == "gtk2"
rm %{buildroot}%{_libdir}/girepository-1.0/AppIndicator3-0.1.typelib
rm %{buildroot}%{_datadir}/gir-1.0/AppIndicator3-0.1.gir
%endif

%post -n libappindicator%{?psuffix:%{psuffix}-}%{sover} -p /sbin/ldconfig

%postun -n libappindicator%{?psuffix:%{psuffix}-}%{sover} -p /sbin/ldconfig

%files -n libappindicator%{?psuffix:%{psuffix}-}%{sover}
%license COPYING COPYING.LGPL.2.1
%doc README
%{_libdir}/libappindicator%{?psuffix}.so.%{sover}*

%if "%{flavor}" == "gtk2"
# Only for GTK 2
%if %{with mono}
%files -n appindicator%{?psuffix}-sharp
%license COPYING COPYING.LGPL.2.1
%doc README
%{_libdir}/appindicator%{?psuffix}-sharp-0.1/
%{_prefix}/lib/mono/appindicator%{?psuffix}-sharp/
%{_prefix}/lib/mono/gac/appindicator%{?psuffix}-sharp/
%{_prefix}/lib/mono/gac/policy.0.0.appindicator%{?psuffix}-sharp/

%files -n appindicator%{?psuffix}-sharp-devel
%license COPYING COPYING.LGPL.2.1
%doc README
%{_libdir}/pkgconfig/appindicator%{?psuffix}-sharp-0.1.pc
%endif

%else

# Only for GTK 3+
%files -n typelib-1_0-AppIndicator%{?psuffix}-0_1
%license COPYING COPYING.LGPL.2.1
%doc README
%{_libdir}/girepository-1.0/AppIndicator%{?psuffix}-0.1.typelib

%endif

%files -n libappindicator%{?psuffix}-devel
%license COPYING COPYING.LGPL.2.1
%doc README
%{_includedir}/libappindicator%{?psuffix}-0.1/
%{_libdir}/libappindicator%{?psuffix}.so
%{_libdir}/pkgconfig/appindicator%{?psuffix}-0.1.pc
%if "%{flavor}" != "gtk2"
%{_datadir}/gir-1.0/AppIndicator%{?psuffix}-0.1.gir
%{_datadir}/vala/vapi/appindicator%{?psuffix}-0.1.*
%endif

%changelog
* Mon Oct 30 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Ensure the src.rpms have unique names between the multibuild
  flavors.
- Disable mono bindings also when building gtk2 flavor: there seems
  to be no consumer left for this.
* Sat Nov 12 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Let the rpm provide libappindicator-gtk3 for EL8 compat
* Sat Nov 20 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 12.10.1~bzr20200706.298 (chages since
  12.10.1~bzr20170215.282):
  * Fix build failures.
  * Vendorise indicator-desktop-shortcuts (convenience wrapper
    around gdesktopappinfo) from the libindicator project, to drop
    the dependency on libindicator as none of the rest of it is
    used.
  * Don't build with -Werror.
  * Drop Python 2 bindings and GObject Introspection for GTK 2
    (lp#1740637).
  * app-indicator: Don't pass unexpected parameter to signal
    emissions (lp#1867996).
  * app-indicator: Only check for item numbers when iterating
    array (lp#1867996).
  * Fall back to tray icon when StatusNotifierHost is not
    available.
- Drop libappindicator-no-Werror.patch: fixed upstream.
- Drop only_require_python_for_gtk2.patch: no longer needed.
- Rebase xappstatusicon.patch.
* Sun Dec 20 2020 Callum Farmer <gmbr3@opensuse.org>
- Provide RH used libappindicator symbol, so third party rpms
  like Mailspring won't complain about missing dependencies
* Fri Aug  7 2020 Michal Vyskocil <mvyskocil@opensuse.org>
- Provide RH used libappindicator-gtk3 symbol, so third party rpms
  like Slack won't complain about missing dependencies
* Tue Jul  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec
* Tue Apr 14 2020 Martin Liška <mliska@suse.cz>
- Add -fcommon in order to fix boo#1164492.
* Thu Apr  9 2020 Dominique Leuenberger <dleuenberger@suse.com>
- Do not apply xappstatusicon.patch: pulls half of Mate into Ring1.
* Mon Mar 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build on py2 less system
* Wed Feb 12 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Added xappstatusicon.patch. It adds support for XAppStatus Icon by
  Linux Mint.
* Sun Feb  2 2020 Matthias Mailänder <mailaender@opensuse.org>
- Use the vanilla nunit for compatibility with newer Mono
* Tue Oct  1 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Make sure the OBS spec file parser does not apply the gtk3 psuffix
  for the default ("") multibuild flavor.
* Wed Sep 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split gtk2 and gtk3 builds using _multibuild. Python2 and Mono
  bindings are only available for GTK2, so the GTK3 version has
  significantly less build dependencies,
  add only_require_python_for_gtk2.patch
- Drop dependency on deprecated gnome-common, see
  https://wiki.gnome.org/Projects/GnomeCommon/Migration
- Allow configure run to succeed even when gtk-doc is not installed,
  add make_gtk_doc_optional.patch
* Wed May 15 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Drop libappindicator-activate-support.patch as it's no longer needed and
  breaks context menu / actions in fall-back mode (boo#1132659)
* Sun Jan 13 2019 ximi.obs@gmail.com
- Changed the activate-support patch to signal an "activate-event"
  so users can create callbacks themselves.
  Original patch from Yichao Yu <yyc1992@gmail.com>.
* Sat Mar 10 2018 dimstar@opensuse.org
- Add libappindicator-no-Werror.patch: the libappindicator code is
  aging and is not keeping up well with the moving world around it.
* Mon Sep  4 2017 dimstar@opensuse.org
- Disable building of -doc subpackage (source not compatible with
  gtk-doc 1.26 - and the doc is available online anyway):
  + Remove gtk-doc BuildRequires.
  + Replace --enable-gtk-doc configure parameter with
  - -disable-gtk-doc,
  + Drop the -doc subpackage.
* Fri Apr 28 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its purpose.
- Update summaries.
- Remove redundant pkgconfig() reqiures; these are already
  autodiscovered.
* Wed Apr 19 2017 sor.alexei@meowr.ru
- Update to version 12.10.1+bzr20170215 (changes since
  12.10.1+bzr20141110):
  * Handle watcher service appearing and disappearing.
  * Make test-simple-app really working.
  * Fix icon and theme paths when running in $SNAP environment
    (lp#1600136).
  * Do not emit label changes when guide is still empty.
  * Do not append the snap prefix if the icon is saved in a well
    known readable path.
- Add libappindicator-activate-support.patch: Open menu on the
  left-click action (lp#1403449).
- Rename python-appindicator to python2-appindicator.
* Thu Jul  7 2016 t.gruner@katodev.de
- Allow building with mono support in case without mono is set
* Mon Jun 13 2016 sor.alexei@meowr.ru
- Little spec cleanup.
* Tue May  5 2015 sor.alexei@meowr.ru
- Update to 12.10.1+bzr20141110:
  * scroll-event: change parameter to the right type.
- Rebase 0001_Fix_mono_dir.patch.
- Remove no-deprecated.patch: merged upstream.
- Remove dont-build-examples.patch: fixed upstream.
- Minor spec cleanup.
* Thu Mar  5 2015 schwab@suse.de
- Allow building without mono support
* Tue Mar 11 2014 p.drouand@gmail.com
- Fix appindicator-sharp require in appindicator-sharp-devel
* Mon Mar 10 2014 p.drouand@gmail.com
- Fix license; src/generate-id.c is released and distributed under
  GPL-3.0 license
* Fri Mar  7 2014 hrvoje.senjan@gmail.com
- Init libappindicator package
- Add 0001_Fix_mono_dir.patch; fix location of .pc files
- Add dont-build-examples.patch; don't build examples
- Add no-deprecated.patch; don't fail on deprecated declarations
